package edu.uoc.main;

import net.tinyos.message.Message;
import net.tinyos.message.MessageListener;
import net.tinyos.message.MoteIF;
import net.tinyos.packet.BuildSource;
import net.tinyos.packet.PhoenixSource;
import net.tinyos.util.PrintStreamMessenger;

import org.apache.commons.cli.CommandLine;
import org.apache.commons.cli.CommandLineParser;
import org.apache.commons.cli.GnuParser;
import org.apache.commons.cli.Options;
import org.apache.commons.cli.ParseException;

import edu.uoc.messages.ConfigMsg;

public class FDConfig implements MessageListener {

	public static FDConfig instance = null;
	public MoteIF amReceiver;
	public MoteIF amSender;
	
	public static void main(String[] args) {

		instance = new FDConfig();
		String source="sf@localhost:9002";
		PhoenixSource phoenix = BuildSource.makePhoenix(source, PrintStreamMessenger.err);

		instance.amReceiver = new MoteIF(phoenix);
		instance.amReceiver.registerListener(new ConfigMsg(), instance);
		
		instance.amSender = new MoteIF(phoenix);
		
		CommandLineParser parser = new GnuParser();
		
		// create Options object
		Options options = new Options();

		// add t option
		options.addOption("m", "mote-id",               true, "Target mote ID");
		options.addOption("T", "temperature-threshold", true, "Umbral máximo de temperatura");
		options.addOption("s", "sensor-interval",       true, "Intervalo de lectura del sensor");
		options.addOption("b", "battery-interval",      true, "Intervalo de lectura de las baterias");
		options.addOption("d", "debug-interval",        true, "Intervalo de lectura del modo \"debug\"");
		options.addOption("e", "enable-debug-mode",     false, "Habilitar el modo \"debug\"");
		options.addOption("D", "disable-debug-mode",    false, "Deshabilitar el modo \"debug\"");
		options.addOption("c", "confirm-alarm",         false, "Confirmar la recepción de la alarma");

		ConfigMsg configMsg = new ConfigMsg();
		
		try {
		    // parse the command line arguments
		    CommandLine line = parser.parse(options, args);

		    if(line.hasOption("m")) {
		        configMsg.set_moteId(Integer.parseInt(line.getOptionValue("m")));
		    } else {
		    	// TODO Print help
		    	System.out.println("Error!");
		    	System.exit(1);
		    }

		    int type = 0;
		    
		    if(line.hasOption("c")) {
		    	AlarmMsgHandler.sendConfirmation(configMsg.get_moteId());
		    } else {

			    if(line.hasOption("b")) {
			        configMsg.set_batteryInterval(formatBinaryTime(Integer.parseInt(line.getOptionValue("b"))));
			        type |= 0x01;
			    }
			    
			    if(line.hasOption("T")) {
			        configMsg.set_temperatureThreshold(formatTemperature(Integer.parseInt(line.getOptionValue("T"))));
			        type |= 0x02;
			    }
			    
			    if(line.hasOption("s")) {
			        configMsg.set_temperatureInterval(formatBinaryTime(Integer.parseInt(line.getOptionValue("s"))));
			        type |= 0x04;
			    }
			    
			    if(line.hasOption("d")) {
			        configMsg.set_temperatureDebugInterval(formatBinaryTime(Integer.parseInt(line.getOptionValue("d"))));
			        type |= 0x08;
			    }
			    
			    if(line.hasOption("e")) {
			    	type |= 0x10;
			    } else if(line.hasOption("D")) {
			    	type |= 0x20;
			    }
	
			    configMsg.set_type((short) type);
			    ConfigMsgHandler.sendConfiguration(configMsg.get_moteId(), configMsg);
		    }
		} catch(ParseException exp) {
		    System.out.println("Unexpected exception: " + exp.getMessage());
		} catch(NumberFormatException nfe) {
			System.out.println("Number format exception: " + nfe.getMessage());
		}

		System.exit(0);
	}

	@Override
	public void messageReceived(int to, Message m) {
		// Com només en tenim registrat d'aquest tipus, el missatge que
		// ens arribarà serà del tipus ConfigMsg
		if(m instanceof ConfigMsg) {
			ConfigMsgHandler.handleConfiguration((ConfigMsg) m);
		}
	}
	
	private static int formatBinaryTime(int time) {
		return Math.round(((float) time * 128)/125);
	}
	
	private static int formatTemperature(int temperature) {
		double adcValue = (double) temperature;
		adcValue *= 10;
		adcValue += 500;
		adcValue /= 2560;
		adcValue *= 1024;
		return Math.round(((float) adcValue));
	}
	
}
