package edu.uoc.main;

import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

import edu.uoc.messages.AlarmMsg;
import edu.uoc.messages.BeaconMsg;
import edu.uoc.messages.ReportMsg;

public class MessageLogger {
	
	private final static SimpleDateFormat dateFormat = new SimpleDateFormat("[dd/MM/yy HH:mm:ss]");
	private final static DecimalFormat temperatureFormat = new DecimalFormat("#0.00");
	private final static DecimalFormat batteryFormat = new DecimalFormat("###0.00");
	
	// Definició de literals
	protected final static String beaconMsgLiteral = " [COBERTURA] ";
	protected final static String alarmMsgLiteral  = " [ALARMA] ";
	protected final static String reportMsgLiteral = " [INFORME] ";

	public static void showTemperatureReport(ReportMsg reportMsg) {
		System.out.println(dateFormat.format(new Date()) + reportMsgLiteral + 
				"La temperatura que registra la mota " + reportMsg.get_moteId() + 
				" és de " + formatTemperature(reportMsg.get_value()) + " ºC.");
	}
	
	public static void showBeaconMessage(BeaconMsg beaconMsg) {
		System.out.println(dateFormat.format(new Date()) + beaconMsgLiteral + 
				"La mota " + beaconMsg.get_moteId() + " ha enviat un paquet amb" +
				" una potència rebuda de " + beaconMsg.get_rssi() + " decibels (dB)");
	}
	
	public static void showTemperatureAlarm(AlarmMsg alarmMsg, String type) {
		System.out.println(dateFormat.format(new Date()) + alarmMsgLiteral + 
				"Atenció! Perill d\'incendi a la sala de la mota " + alarmMsg.get_moteId() + 
				". S\'ha activat una alarma " + type + " amb una temperatura llegida de " + 
				formatTemperature(alarmMsg.get_value()) + " ºC.");
	}
	
	public static void showBatteryAlarm(AlarmMsg alarmMsg) {
		System.out.println(dateFormat.format(new Date()) + alarmMsgLiteral + 
				"Avís! La mota " + alarmMsg.get_moteId() + " té la batería baixa. " +
				"S\'ha activat una alarma perquè la càrrega actual es de " + 
				formatBattery(alarmMsg.get_value()) + " mV.");
	}
	
	public static void showBatteryReport(ReportMsg reportMsg) {
		System.out.println(dateFormat.format(new Date()) + reportMsgLiteral + 
				"La mota " + reportMsg.get_moteId() + " té la batería de " + 
				formatBattery(reportMsg.get_value()) + " mV.");
	}

	private static String formatTemperature(int counts) {
		double realTemp = (double) counts;
		realTemp /= 1024;
		realTemp *= 2560;
		realTemp -= 500;
		realTemp /= 10;
		return temperatureFormat.format(realTemp);
	}
	
	private static String formatBattery(int counts) {
		double realBat = (double) counts;
		realBat /= 1024;
		realBat *= 5120;
		return batteryFormat.format(realBat);
	}
	
}
