package edu.uoc.main;

import java.util.HashMap;
import java.util.Map;

import edu.uoc.messages.ReportMsg;
import edu.uoc.timecontrol.BatteryTimer;

public class ReportMsgHandler {

	private final static byte RPRT_TEMPERATURE = 0x01;
	private final static byte RPRT_BATTERY     = 0x02;
	private final static int  BAT_INTERVAL     = 10000;
	
	public static Map<Integer, BatteryTimer> batteryTimers = new HashMap<Integer, BatteryTimer>();
	
	public static void handleReport(ReportMsg report) {
		byte type = (byte) report.get_type();

		// Apliquem aquesta màscara perque de moment només ens interessen els
		// 4 bits de menor pes.
		switch(type & 0x0F) {
		case RPRT_TEMPERATURE:
			handleTemperatureReport(report);
			break;
		case RPRT_BATTERY:
			handleBatteryReport(report);
			break;
		default:
			System.out.println("Report desconegut:" + report.toString());
		}
	}

	private static void handleTemperatureReport(ReportMsg report) {
		MessageLogger.showTemperatureReport(report);
	}

	private static void handleBatteryReport(ReportMsg report) {
		int moteId = report.get_moteId();
//		MessageLogger.showBatteryReport(report);
		if(batteryTimers.containsKey(moteId)) {
			(batteryTimers.get(moteId)).updateLastReception();
		} else {
			batteryTimers.put(moteId, new BatteryTimer(moteId, BAT_INTERVAL));
		}
	}

}
