#ifndef FIRE_DETECTOR_H
#define FIRE_DETECTOR_H

#ifndef RF230_HARDWARE_ACK
#define RF230_HARDWARE_ACK
#endif

// Valors per defecte
enum {
	TEMP_ALARM        = 320,
	BAT_LVL_ALARM     = 400,
	TEMP_INTERVAL     = 4096,
	TEMP_DBG_INTERVAL = 10240,
	BAT_INTERVAL      = 10240
};

// Màscares pel tipus d'alarma
enum {
	ALARM_SENT				= 0x10,
	ALARM_SW_ACKED			= 0x20,
	CONFIRMATION_SENT		= 0x40,
	CONFIRMATION_SW_ACKED	= 0x80,
};


// Màscares pel tipus de missatge d'alarma
enum {
	ALRM_TEMPERATURE = 0x01,
	ALRM_BATTERY     = 0x02,
	ALRM_AUTOMATIC   = 0x04,
	ALRM_MANUAL      = 0x08
};

// Màscares pel tipus de missatge de reporting
enum {
	RPRT_TEMPERATURE = 0x01,
	RPRT_BATTERY     = 0x02
};

// Màscares pel tipus de missatge de configuració
enum {
	CFG_BAT_INTERVAL  = 0x01,
	CFG_TEMP_ALARM    = 0x02,
	CFG_TEMP_INTERVAL = 0x04,
	CFG_DBG_INTERVAL  = 0x08,
	CFG_DBG_ON        = 0x10,
	CFG_DBG_OFF       = 0x20
};

// Màscares per saber el tipus de reset
enum {
	POWER_ON_RESET = 0x01,
	EXTERNAL_RESET = 0x02,
	WATCHDOG_RESET = 0x08
};

// Direcció de la memòria on guardar l'estat persistent
enum {
	CONFIG_ADDR = 0x400
};

// Direcció de la mota Estació Base
enum {
	STATION_ID = 1
};

// Estats globals de l'aplicació FireDetector
enum {
	IDLE     = 1,
	DETECTOR = 2,
	TEST     = 3
};

// Estats individuals de cada mòdul que ofereix SplitControl
enum {
	STARTING,
	STARTING_RADIO,
	STARTING_SENSORS,
	RADIO_STARTED,
	RADIO_IDLE,
	RADIO_SENDING,
	SENSORS_STARTED,
	STARTED,
	STOPPING,
	STOPPING_RADIO,
	STOPPING_SENSORS,
	RADIO_STOPPED,
	SENSORS_STOPPED,
	STOPPED
};

enum {
	AM_ALARMMSG		= 40,
	AM_REPORTMSG	= 41,
	AM_CONFIGMSG	= 42,
	AM_BEACONMSG	= 43
};

typedef struct PersistedConfiguration {
	bool     debugActivated;
	uint8_t  currentState;
	uint16_t temperatureThreshold;
	uint16_t temperatureInterval;
	uint16_t temperatureDebugInterval;
	uint16_t batteryInterval;
} PersistedConfiguration;

typedef nx_struct BeaconMsg {
	nx_uint16_t moteId;
	nx_uint8_t  rssi;
} BeaconMsg;

typedef nx_struct ReportMsg {
	nx_uint8_t  type;
	nx_uint16_t moteId;
	nx_uint16_t value;
} ReportMsg;

typedef nx_struct AlarmMsg {
	nx_uint8_t  type;
	nx_uint16_t moteId;
	nx_uint16_t value;
} AlarmMsg;

typedef nx_struct ConfigMsg {
	nx_uint8_t  type;
	nx_uint16_t moteId;
	nx_uint16_t batteryInterval;
	nx_uint16_t temperatureThreshold;
	nx_uint16_t temperatureInterval;
	nx_uint16_t temperatureDebugInterval;
} ConfigMsg;

#endif /* FIRE_DETECTOR_H */
